@@ -1,5 +1,5 @@
 ;;;; File: test-compat-spec.scm
-;;;; Copyright (C) 2004 Andreas Rottmann
+;;;; Copyright (C) 2004, 2007 Andreas Rottmann
 ;;;;
 ;;;; This program is free software; you can redistribute it and/or
 ;;;; modify it under the terms of the GNU Lesser General Public
@@ -39,4 +39,14 @@
    '<gw:void>
    "gw_test_gw_standard_no_op"
    '()
-   "Do nothing"))
+   "Do nothing")
+
+  (gw:wrap-as-wct ws '<gw:TestParentObj*> "gwTestParentObj*" "const gwTestParentObj*")
+  
+  (gw:wrap-function
+   ws
+   'gw-test-parent-same-obj
+   '<gw:TestParentObj*>
+   "gw_test_parent_same_obj"
+   '((<gw:TestParentObj*> data))
+   "Return the gwTestParentObj*."))
