@@ -38,6 +38,19 @@ int gw_test_retval_exception (int arg)
     return 0;
 }
 
+int gw_test_invisible_out_arg (int in, int *out1, int *out2)
+{
+  *out1 = in * in;
+  *out2 = in > 100;
+  return in;
+}
+
+int gw_test_many_args (int i1, int i2, int i3, int i4, int i5, int i6,
+                       int i7, int i8, int i9, int i10, int i11)
+{
+  return i1 + i2 + i3 + i4 + i5 + i6 + i7 + i8 + i9 + i10 + i11;
+}
+
 /*======================================================================*/
 /* Generics */
 
